#
# spec file for package fuse-oscfs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fuse-oscfs
Version:        0.9.0
Release:        1.4
Summary:        A FUSE file system for accessing Open Build Service instances
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://github.com/mgerstner/oscfs
Source:         oscfs-%{version}.tar.xz
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
Requires:       osc
Requires:       python3-fusepy
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       python2-oscfs = %version-%release
Obsoletes:      python2-oscfs < %version-%release

%description
oscfs is a FUSE-based user space file system for accessing Open
Build Service (OBS) instances. It is based on the osc (openSUSE Commander)
Python package for interfacing with OBS. At the moment, it provides read-only
access for inspecting packages and their metadata.

%prep
%setup -q -n oscfs-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc README.md NEWS.rst
%license LICENSE.txt
%{python3_sitelib}/*
%{_bindir}/oscfs

%changelog
* Fri Oct 20 2023 matthias.gerstner@suse.com
- Update to version 0.9.0:
  * NEWS: changes for next release
  * regtest: compatibility with newer OSC module versions
  * obs: implement transparent retry to prevent HTTP 503 woes
  * obs: remove extraneous newlines from project and package meta output
  * error handling: support full exception backtrace report
  * debugging: support writing stdout and stderr to a logfile for analysis
  * regtest: fix unmount in early auth error failure case
  * regtest: make sure also to remove cookiejar for early auth error test
  * Revert "regtest: add some extra robustness against potential umount races"
  * regtest: add some extra robustness against potential umount races
  * fix regressions introduced by commit cd692a1d2f9fabe4ac5451832c3b7df109302c07
  * urlopenwrapper: fix sshkey check
  * Package: fix symlink path to update package
  * urlopen wrapper: support disabling the wrapper on the command line
  * obs.getBinaries(): fix strange osc behaviour if zero length files appear
  * add command line option to disable build artifacts caching
  * module_helper: insert local modules directory at the front of the path
  * oscfs wrapper script: use explicitly python3 by default
  * bugfix: fix early auth check on non-OBS instance
* Wed Feb 23 2022 matthias.gerstner@suse.com
- Update to version v0.8.1:
  * urlopenwrapper: make data an optional argument, fixing a start error on
    some Python versions.
* Tue Feb 22 2022 matthias.gerstner@suse.com
- Update to version v0.8.0:
  - fix error if a package filename contained the '#' character.
  - fix authentication error detection during startup.
  - enable urlopenwrapper hack again which speeds up consecutive requests
    drastically.
  - source code ported to Python3 only, removed all Python2 compatibility.
    Source code is now conforming largely to PIP and flake8 standards.
* Wed Mar  3 2021 matthias.gerstner@suse.com
- Update to version v0.7.2:
  * obs getBuildlog(): return plain binary data instead of utf8 decoded string
  * types: avoid encoding content during read() which can change the content size
  * types: actually import sys to avoid error during error handling
  * unicode handling: only use `unicode` on Python2
* Fri Feb 21 2020 matthias.gerstner@suse.com
- Update to version 0.7.1:
  - fix read() with offset especially with large files. This fixes use of
    various tools when applied on oscfs files e.g. `rpm2cpio` or
    `tail *.spec` previously failed or behaved strangely.
  - be robust against non-ASCII characters in OBS buildlogs.
  - apply caching also to actual file content to be more efficient when e.g.
    operating on larger files.
* Mon May 27 2019 mgerstner <matthias.gerstner@suse.com>
- major update to version 0.7.0:
  - Added support for running in Python3 with the Python3 osc module installed.
  - support mounting of oscfs in non-empty directories.
  - minor bugfixes with accessing package and project meta data via `.oscfs`.
* Thu Aug  9 2018 matthias.gerstner@suse.com
- minor update to version 0.6.1:
  - fix bad read speed when accessing package binaries via
    `.oscfs/binaries/...`
* Thu Jul 12 2018 jengelh@inai.de
- Fix grammar in description.
* Thu Jul 12 2018 matthias.gerstner@suse.com
- initial version of new package for oscfs. This is currently a python2-only
  package.
